Re-exports
pub use crate::generator_state::GeneratorState;
Modules
Macros
Structs
Traits
Functions
- generator
- To build generator, pass an async function with two parameters: First parameter is Yielder – context handle to yield generated item The second parameter – it’s a Resume value passed to the Generator::resume() method at the first time